@@ -22,37 +22,29 @@ class Microphone():
         self.device_id = device_id
         self.zero_counter = 0
 
-        input_devices = self.listAvailableDevices()
-        if not device_id:
+        while not self.device_id or not self.checkDeviceModelCompatibility(self.device_id):
+            input_devices = self.listAvailableDevices()
+            input_device_id = int(input("Type the id of the audio device you want to use: \n"))
             for device in input_devices:
-                try:
-                    supported = self.interface.is_format_supported(rate,
-                                    input_device=device[0],
-                                    input_channels=channels,
-                                    input_format=pyaudio.paInt16)
-                    if supported:
-                        self.device_id = device[0]
-                        break
-                except:
-                    print('device [%i] %s does not support the model requirements'% (device[0],device[1]))
-                    print(rate, channels)
-                    None
-
-        try:
-            if not self.device_id:
-                raise Exception()
-
-            supported = self.interface.is_format_supported(rate,
-                        input_device=self.device_id,
-                        input_channels=channels,
-                        input_format=pyaudio.paInt16)
-            if not supported:
-                raise Exception()
-        except:
-            raise Exception('Device id %i does not suport the format required by the model' % self.device_id)
+                if device[0] == input_device_id:
+                      if self.checkDeviceModelCompatibility(input_device_id):
+                          self.device_id = input_device_id
 
         print('selected Audio device: %i'% self.device_id)
 
+    def checkDeviceModelCompatibility(self, device_id):
+        supported = False
+        try:
+            supported = self.interface.is_format_supported(self.rate,
+                        input_device=device_id,
+                        input_channels=self.channels,
+                        input_format=pyaudio.paInt16)
+        except:
+            supported = False
+        finally:
+            return supported
+
+
 
     def listAvailableDevices(self):
         if not self.interface:
